@@ -6,8 +6,8 @@ geometry
 .. currentmodule:: compas.geometry
 
 
-Bases
-=====
+Base Classes
+============
 
 .. autosummary::
     :toctree: generated/
@@ -15,8 +15,6 @@ Bases
 
     Primitive
     Shape
-    Collection
-    CollectionNumpy
 
 
 Primitives
@@ -54,15 +52,43 @@ Shapes
     Torus
 
 
-Collections
-===========
+Predicates 2D
+=============
 
 .. autosummary::
     :toctree: generated/
     :nosignatures:
 
-    PointCollection
-    PointCollectionNumpy
+    is_ccw_xy
+    is_colinear_xy
+    is_polygon_convex_xy
+    is_point_on_line_xy
+    is_point_on_segment_xy
+    is_point_on_polyline_xy
+    is_point_in_triangle_xy
+    is_point_in_polygon_xy
+    is_point_in_convex_polygon_xy
+    is_point_in_circle_xy
+    is_polygon_in_polygon_xy
+
+
+Predicates 3D
+=============
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    is_colinear
+    is_coplanar
+    is_point_in_halfspace
+    is_point_in_polyhedron
+    is_point_in_sphere
+    is_point_on_line
+    is_point_on_plane
+    is_point_on_polyline
+    is_point_on_segment
+    is_polygon_convex
 
 
 Transformations
@@ -147,6 +173,7 @@ Transformations
     quaternion_canonize
     quaternion_conjugate
 
+
 Linear algebra
 ==============
 
@@ -191,6 +218,10 @@ Linear algebra
     transpose_matrix
     vector_component
     vector_component_xy
+    vector_average
+    vector_variance
+    vector_standard_deviation
+
 
 Points, Vectors, Lines, Planes
 ==============================
@@ -203,12 +234,15 @@ Points, Vectors, Lines, Planes
     angle_points_xy
     angle_vectors
     angle_vectors_xy
+    angle_vectors_signed
     angles_points
     angles_points_xy
     angles_vectors
     angles_vectors_xy
+    angle_planes
     centroid_points
     centroid_points_xy
+    centroid_points_weighted
     distance_line_line
     distance_point_line
     distance_point_line_xy
@@ -223,14 +257,11 @@ Points, Vectors, Lines, Planes
     midpoint_point_point_xy
     midpoint_line
     midpoint_line_xy
-    weighted_centroid_points
+
 
 Polygons & Polyhedrons
 ======================
 
-.. rename functions?
-   type of object first
-
 .. autosummary::
     :toctree: generated/
     :nosignatures:
@@ -251,8 +282,9 @@ Polygons & Polyhedrons
     normal_triangle_xy
     volume_polyhedron
 
-Pointclouds
-===========
+
+Point Sets
+==========
 
 .. autosummary::
     :toctree: generated/
@@ -264,50 +296,12 @@ Pointclouds
     convex_hull_numpy
     convex_hull_xy
     convex_hull_xy_numpy
-    delaunay_from_points
-    delaunay_from_points_numpy
-    icp_numpy
     oriented_bounding_box_numpy
     oriented_bounding_box_xy_numpy
-    voronoi_from_points_numpy
 
-Queries
-=======
 
-.. autosummary::
-    :toctree: generated/
-    :nosignatures:
-
-    is_ccw_xy
-    is_colinear
-    is_colinear_xy
-    is_coplanar
-    is_intersection_line_line
-    is_intersection_line_line_xy
-    is_intersection_line_plane
-    is_intersection_line_triangle
-    is_intersection_plane_plane
-    is_intersection_segment_plane
-    is_intersection_segment_segment
-    is_intersection_segment_segment_xy
-    is_polygon_convex
-    is_polygon_convex_xy
-    is_point_in_circle
-    is_point_in_circle_xy
-    is_point_in_convex_polygon_xy
-    is_point_on_line
-    is_point_on_line_xy
-    is_point_on_plane
-    is_point_infront_plane
-    is_point_in_polygon_xy
-    is_point_on_polyline
-    is_point_on_segment
-    is_point_on_segment_xy
-    is_point_in_triangle
-    is_point_in_triangle_xy
-
-Proximity
-=========
+Distance
+========
 
 .. autosummary::
     :toctree: generated/
@@ -323,6 +317,7 @@ Proximity
     closest_point_on_segment
     closest_point_on_segment_xy
 
+
 Intersections
 =============
 
@@ -337,8 +332,18 @@ Intersections
     intersection_line_triangle
     intersection_plane_plane
     intersection_plane_plane_plane
+    intersection_segment_segment
     intersection_segment_segment_xy
     intersection_segment_plane
+    is_intersection_line_line
+    is_intersection_line_line_xy
+    is_intersection_line_plane
+    is_intersection_line_triangle
+    is_intersection_plane_plane
+    is_intersection_segment_plane
+    is_intersection_segment_segment
+    is_intersection_segment_segment_xy
+
 
 Offsets
 =======
@@ -351,39 +356,22 @@ Offsets
     offset_polyline
     offset_polygon
 
-Other functions
-===============
 
-**Smoothing**
-
-.. autosummary::
-    :toctree: generated/
-    :nosignatures:
-
-    smooth_centroid
-    smooth_centerofmass
-    smooth_area
-
-**Planarisation**
-
-.. autosummary::
-    :toctree: generated/
-    :nosignatures:
-
-    flatness
-    planarize_faces
-
-**Interpolation**
+Interpolation
+=============
 
 .. autosummary::
     :toctree: generated/
     :nosignatures:
 
+    barycentric_coordinates
     discrete_coons_patch
     tween_points
     tween_points_distance
 
-**Bestfit**
+
+Fitting
+=======
 
 .. autosummary::
     :toctree: generated/
@@ -393,13 +381,55 @@ Other functions
     bestfit_plane
     bestfit_plane_numpy
 
-**Isolines**
+
+Boolean operations
+==================
 
 .. autosummary::
     :toctree: generated/
     :nosignatures:
 
-    scalarfield_contours_numpy
+    boolean_union_mesh_mesh
+    boolean_difference_mesh_mesh
+    boolean_intersection_mesh_mesh
+
+
+Triangulation
+=============
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    delaunay_from_points
+    delaunay_from_points_numpy
+    voronoi_from_points_numpy
+
+
+Triangle meshes
+===============
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+
+Quad meshes
+===========
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+
+Pointclouds
+===========
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    icp_numpy
 
 """
 from __future__ import absolute_import
@@ -407,21 +437,25 @@ from __future__ import division
 from __future__ import print_function
 
 from ._core import *  # noqa: F401 F403
-from ._transformations import *  # noqa: F401 F403
-from ._primitives import *  # noqa: F401 F403
-from ._shapes import *  # noqa: F401 F403
-from ._collections import *  # noqa: F401 F403
+
+from .predicates import *  # noqa: F401 F403
+from .intersections import *  # noqa: F401 F403
+from .transformations import *  # noqa: F401 F403
+
+from .primitives import *  # noqa: F401 F403
+from .shapes import *  # noqa: F401 F403
+from .collections import *  # noqa: F401 F403
 
 from .bbox import *  # noqa: F401 F403
 from .bestfit import *  # noqa: F401 F403
+from .booleans import *  # noqa: F401 F403
 from .hull import *  # noqa: F401 F403
 from .icp import *  # noqa: F401 F403
 from .interpolation import *  # noqa: F401 F403
-from .isolines import *  # noqa: F401 F403
 from .offset import *  # noqa: F401 F403
-from .planarisation import *  # noqa: F401 F403
-from .smoothing import *  # noqa: F401 F403
-from .spatial import *  # noqa: F401 F403
+from .quadmesh import *  # noqa: F401 F403
 from .triangulation import *  # noqa: F401 F403
+from .trimesh import *  # noqa: F401 F403
+
 
 __all__ = [name for name in dir() if not name.startswith('_')]
